Index: trunk/BNC/src/RTCM3/RTCM3Decoder.cpp
===================================================================
--- trunk/BNC/src/RTCM3/RTCM3Decoder.cpp	(revision 6597)
+++ trunk/BNC/src/RTCM3/RTCM3Decoder.cpp	(revision 6598)
@@ -78,5 +78,5 @@
   connect(this, SIGNAL(newGalileoEph(t_ephGal)), BNC_CORE, SLOT(slotNewGalileoEph(t_ephGal)));
   connect(this, SIGNAL(newSBASEph(t_ephSBAS)),   BNC_CORE, SLOT(slotNewSBASEph(t_ephSBAS)));
-  connect(this, SIGNAL(newCompassEph(t_ephCompass)), BNC_CORE, SLOT(slotNewCompassEph(t_ephCompass)));
+  connect(this, SIGNAL(newBDSEph(t_ephBDS)),     BNC_CORE, SLOT(slotNewBDSEph(t_ephBDS)));
 
   // Mode can be either observations or corrections
@@ -262,8 +262,8 @@
               }
 
-              // COMPASS
+              // BDS
               // -------------
-              else if (satID >= PRN_COMPASS_START && satID <= PRN_COMPASS_END) {
-                obs._prn.set('C', satID - PRN_COMPASS_START + 1);
+              else if (satID >= PRN_BDS_START && satID <= PRN_BDS_END) {
+                obs._prn.set('C', satID - PRN_BDS_START + 1);
               }
 
@@ -412,10 +412,10 @@
           }
 
-          // COMPASS Ephemeris
+          // BDS Ephemeris
           // -----------------
-          else if (rr == 63) {
-            decoded = true;
-//            t_ephCompass eph; eph.set(&parser.ephemerisCompass);
-//            emit newCompassEph(eph);
+          else if (rr == RTCM3ID_BDS) {
+            decoded = true;
+            t_ephBDS eph; eph.set(&parser.ephemerisBDS);
+            emit newBDSEph(eph);
           }
         }
Index: trunk/BNC/src/RTCM3/RTCM3Decoder.h
===================================================================
--- trunk/BNC/src/RTCM3/RTCM3Decoder.h	(revision 6597)
+++ trunk/BNC/src/RTCM3/RTCM3Decoder.h	(revision 6598)
@@ -52,5 +52,5 @@
   void newSBASEph(t_ephSBAS eph);
   void newGalileoEph(t_ephGal eph);
-  void newCompassEph(t_ephCompass eph);
+  void newBDSEph(t_ephBDS eph);
 
  private:
Index: trunk/BNC/src/bnccore.h
===================================================================
--- trunk/BNC/src/bnccore.h	(revision 6597)
+++ trunk/BNC/src/bnccore.h	(revision 6598)
@@ -80,5 +80,5 @@
   void slotNewGalileoEph(t_ephGal);
   void slotNewSBASEph(t_ephSBAS);
-  void slotNewCompassEph(t_ephCompass);
+  void slotNewBDSEph(t_ephBDS);
   void slotNewOrbCorrections(QList<t_orbCorr>);
   void slotNewClkCorrections(QList<t_clkCorr>);
@@ -94,5 +94,5 @@
   void newSBASEph(t_ephSBAS eph);
   void newGalileoEph(t_ephGal eph);
-  void newCompassEph(t_ephCompass eph);
+  void newBDSEph(t_ephBDS eph);
   void newOrbCorrections(QList<t_orbCorr>);
   void newClkCorrections(QList<t_clkCorr>);
Index: trunk/BNC/src/bncephuser.h
===================================================================
--- trunk/BNC/src/bncephuser.h	(revision 6597)
+++ trunk/BNC/src/bncephuser.h	(revision 6598)
@@ -42,5 +42,5 @@
   void slotNewGalileoEph(t_ephGal);
   void slotNewSBASEph(t_ephSBAS);
-  void slotNewCompassEph(t_ephCompass);
+  void slotNewBDSEph(t_ephBDS);
 
  public:

Index: trunk/BNC/src/bnccore.cpp
===================================================================
--- trunk/BNC/src/bnccore.cpp	(revision 6597)
+++ trunk/BNC/src/bnccore.cpp	(revision 6598)
@@ -119,5 +119,5 @@
   qRegisterMetaType<t_ephGal>               ("t_ephGal");
   qRegisterMetaType<t_ephSBAS>              ("t_ephSBAS");
-  qRegisterMetaType<t_ephCompass>           ("t_ephCompass");
+  qRegisterMetaType<t_ephBDS>               ("t_ephBDS");
   qRegisterMetaType<QList<t_orbCorr> >      ("QList<t_orbCorr>");
   qRegisterMetaType<QList<t_clkCorr> >      ("QList<t_clkCorr>");
@@ -250,9 +250,9 @@
 }
 
-// New Compass Ephemeris
-////////////////////////////////////////////////////////////////////////////
-void t_bncCore::slotNewCompassEph(t_ephCompass eph) {
+// New BDS Ephemeris
+////////////////////////////////////////////////////////////////////////////
+void t_bncCore::slotNewBDSEph(t_ephBDS eph) {
   if (checkPrintEph(&eph) == success) {
-    emit newCompassEph(eph);
+    emit newBDSEph(eph);
   }
 }
Index: trunk/BNC/src/bncephuser.cpp
===================================================================
--- trunk/BNC/src/bncephuser.cpp	(revision 6597)
+++ trunk/BNC/src/bncephuser.cpp	(revision 6598)
@@ -1,3 +1,2 @@
-// Part of BNC, a utility for retrieving decoding and
 // converting GNSS data streams from NTRIP broadcasters.
 //
@@ -62,6 +61,6 @@
             this, SLOT(slotNewSBASEph(t_ephSBAS)), Qt::DirectConnection);
 
-    connect(BNC_CORE, SIGNAL(newCompassEph(t_ephCompass)),
-            this, SLOT(slotNewCompassEph(t_ephCompass)), Qt::DirectConnection);
+    connect(BNC_CORE, SIGNAL(newBDSEph(t_ephBDS)),
+            this, SLOT(slotNewBDSEph(t_ephBDS)), Qt::DirectConnection);
   }
 }
@@ -104,7 +103,7 @@
 }
 
-// New Compass Ephemeris
-////////////////////////////////////////////////////////////////////////////
-void bncEphUser::slotNewCompassEph(t_ephCompass eph) {
+// New BDS Ephemeris
+////////////////////////////////////////////////////////////////////////////
+void bncEphUser::slotNewBDSEph(t_ephBDS eph) {
   putNewEph(&eph, false);
 }
@@ -128,5 +127,5 @@
   const t_ephGal*     ephGal     = dynamic_cast<const t_ephGal*>(eph);
   const t_ephSBAS*    ephSBAS    = dynamic_cast<const t_ephSBAS*>(eph);
-  const t_ephCompass* ephCompass = dynamic_cast<const t_ephCompass*>(eph);
+  const t_ephBDS*     ephBDS     = dynamic_cast<const t_ephBDS*>(eph);
 
   t_eph* newEph = 0;
@@ -144,6 +143,6 @@
     newEph = new t_ephSBAS(*ephSBAS);
   }
-  else if (ephCompass) {
-    newEph = new t_ephCompass(*ephCompass);
+  else if (ephBDS) {
+    newEph = new t_ephBDS(*ephBDS);
   }
   else {